tiki2po — Translate Toolkit 2.5.0 documentation

# tiki2po

Converts TikiWiki language.php files to Gettext PO format.

## Usage

    tiki2po [options] <tiki> <po>
    po2tiki [options] <po> <tiki>

Where:

<tiki> | is a valid language.php file for TikiWiki
<po> | is a PO file

Options (tiki2po):

`--version` | show program’s version number and exit
`-h, --help` | show this help message and exit
`--manpage` | output a manpage based on the help
`--progress=PROGRESS`
| show progress as: dots, none, bar, names, verbose
`--errorlevel=ERRORLEVEL`
| show errorlevel as: none, message, exception, traceback
`-i INPUT, --input=INPUT`
| read from INPUT in php format
`-x EXCLUDE, --exclude=EXCLUDE`
| exclude names matching EXCLUDE from input paths
`-o OUTPUT, --output=OUTPUT`
| write to OUTPUT in po, pot formats
`-S, --timestamp`
| skip conversion if the output file has newer timestamp
`--include-unused`
| When converting, include strings in the “unused” section?

Options (po2tiki):

`--version` | show program’s version number and exit
`-h, --help` | show this help message and exit
`--manpage` | output a manpage based on the help
`--progress=PROGRESS`
| show progress as: dots, none, bar, names, verbose
`--errorlevel=ERRORLEVEL`
| show errorlevel as: none, message, exception, traceback
`-i INPUT, --input=INPUT`
| read from INPUT in po, pot formats
`-x EXCLUDE, --exclude=EXCLUDE`
| exclude names matching EXCLUDE from input paths
`-o OUTPUT, --output=OUTPUT`
| write to OUTPUT in php format
`-S, --timestamp`
| skip conversion if the output file has newer timestamp

## Examples

These examples demonstrate the use of tiki2po:

    tiki2po language.php language.po

Convert the tiki language.php file to .po:

    po2tiki language.po language.php

Convert a .po file to a tiki language.php file

## Notes

- Templates are not currently supported.